@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,7 +23,7 @@
 #include "mailimporter/filterinfo.h"
 #include "mailimporter/othermailerutil.h"
 
-#include <kpluginfactory.h>
+#include <KPluginFactory>
 
 #include <QDir>
 
